/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.util.jmx;

import javax.management.MBeanAttributeInfo;
import javax.management.modelmbean.ModelMBeanAttributeInfo;

/**
 * Implementations of this class can be added dynamically as attributes in a BaseModelMBeanExt.
 * @author missonng
 */
public abstract class AbstractMBeanAttribute {
    /**
     * The MBeanAttributeInfo describing this attribute.
     */
    private ModelMBeanAttributeInfo info;

    /**
     * The AbstractMBeanAttribute constructor.
     * @param name The name of the attribute.
     * @param type The type or class name of the attribute.
     * @param description A human readable description of the attribute.
     * @param isReadable True if the attribute has a getter method, false otherwise.
     * @param isWritable True if the attribute has a setter method, false otherwise.
     * @param isIs True if this attribute has an "is" getter, false otherwise.
     */
    public AbstractMBeanAttribute(final String name, final String type, final String description,
            final boolean isReadable, final boolean isWritable, final boolean isIs) {
        this.info = new ModelMBeanAttributeInfo(name, type, description, isReadable, isWritable, isIs);
    }

    /**
     * Get the MBeanAttributeInfo describing this attribute.
     * @return The MBeanAttributeInfo describing this attribute.
     */
    public MBeanAttributeInfo getMBeanAttributeInfo() {
        return this.info;
    }

    /**
     * Get the attributes value.
     * @return The attributes value.
     */
    public abstract Object getValue();

    /**
     * Set the attribute value.
     * @param value The attributes value.
     */
    public abstract void setValue(Object value);
}
